# superjacob is a package for automatic differentiation

[![Build Status](https://travis-ci.com/ADMonsters/cs207-FinalProject.svg?branch=master)](https://travis-ci.com/ADMonsters/cs207-FinalProject)

[![codecov](https://codecov.io/gh/ADMonsters/cs207-FinalProject/branch/master/graph/badge.svg)](https://codecov.io/gh/ADMonsters/cs207-FinalProject)

## A guide for using this package can be found in docs/documentation.ipynb (How to Use section)

## Developed by CS 207 Group 2

- Benjamin Levy
- Mark Miao
- Kidus Negesse
- Zhenru Wang
